@@ -10,7 +10,7 @@
 #include <time.h>
 #include <libecal/libecal.h>
 
-#include "common/e-soap-message.h"
+#include "common/e-soap-request.h"
 #include "common/e-ews-item.h"
 
 G_BEGIN_DECLS
@@ -26,14 +26,14 @@ typedef struct _EEWSFreeBusyData {
 } EEWSFreeBusyData;
 
 gboolean	e_ews_cal_utils_prepare_free_busy_request
-						(ESoapMessage *msg,
+						(ESoapRequest *request,
 						 gpointer user_data, /* EEWSFreeBusyData * */
 						 GError **error);
-void		e_ews_cal_utils_set_time	(ESoapMessage *msg,
+void		e_ews_cal_utils_set_time	(ESoapRequest *request,
 						 const gchar *name,
 						 ICalTime *tt,
 						 gboolean with_timezone);
-gboolean	e_ews_cal_utils_set_recurrence	(ESoapMessage *msg,
+gboolean	e_ews_cal_utils_set_recurrence	(ESoapRequest *request,
 						 ICalComponent *comp,
 						 gboolean server_satisfies_2013,
 						 GError **error);
