@@ -20,10 +20,6 @@ const gchar *	e_ews_connection_get_server_version_string
 EEwsServerVersion
 		e_ews_debug_get_server_version_from_string
 							(const gchar *version);
-void		e_ews_debug_dump_raw_soup_request
-							(SoupMessage *msg);
-void		e_ews_debug_dump_raw_soup_response
-							(SoupMessage *msg);
 const gchar *	e_ews_debug_redact_headers		(gchar direction,
 							 const gchar *data);
 void		e_ews_debug_soup_log_printer_stdout	(SoupLogger *logger,
