@@ -107,10 +107,11 @@ ebb_m365_contact_get_birthday (EBookBackendM365 *bbm365,
 			       GError **error)
 {
 	time_t value;
+	gboolean exists = FALSE;
 
-	value = e_m365_contact_get_birthday (m365_contact);
+	value = e_m365_contact_get_birthday (m365_contact, &exists);
 
-	if (value > (time_t) 0) {
+	if (exists) {
 		EContactDate dt;
 		struct tm stm;
 
@@ -1076,7 +1077,7 @@ ebb_m365_contact_photo_equal (EContactPhoto *photo1,
 	if (!data1 && !data2)
 		return TRUE;
 
-	return len1 == len2 &&
+	return len1 == len2 && data1 && data2 &&
 		memcmp (data1, data2, len1) == 0;
 }
 
