@@ -9,9 +9,6 @@
 #include <glib/gi18n-lib.h>
 #include <glib/gstdio.h>
 
-#include <libemail-engine/libemail-engine.h>
-#include <e-util/e-util.h>
-
 #include "common/camel-m365-settings.h"
 #include "common/e-m365-connection.h"
 #include "camel-m365-folder.h"
@@ -198,7 +195,7 @@ m365_store_read_default_folders (CamelM365Store *m365_store,
 		message = soup_message_new (SOUP_METHOD_GET, uri);
 
 		if (!message) {
-			g_set_error (error, SOUP_HTTP_ERROR, SOUP_STATUS_MALFORMED, _("Malformed URI: “%s”"), uri);
+			g_set_error (error, G_IO_ERROR, G_IO_ERROR_INVALID_DATA, _("Malformed URI: “%s”"), uri);
 
 			g_ptr_array_unref (requests);
 			g_free (uri);
@@ -222,7 +219,8 @@ m365_store_read_default_folders (CamelM365Store *m365_store,
 			SoupMessage *message = g_ptr_array_index (requests, ii);
 			JsonNode *node = NULL;
 
-			if (message->status_code > 0 && SOUP_STATUS_IS_SUCCESSFUL (message->status_code) &&
+			if (e_m365_connection_util_get_message_status_code (message) > 0 &&
+			    SOUP_STATUS_IS_SUCCESSFUL (e_m365_connection_util_get_message_status_code (message)) &&
 			    e_m365_connection_json_node_from_message (message, NULL, &node, cancellable, NULL) &&
 			    node && JSON_NODE_HOLDS_OBJECT (node)) {
 				JsonObject *object = json_node_get_object (node);
@@ -311,7 +309,7 @@ m365_store_save_category_changes (GHashTable *old_categories, /* gchar *id ~> Ca
 
 	evo_labels = g_ptr_array_new_full (5, g_free);
 
-	settings = e_util_ref_settings ("org.gnome.evolution.mail");
+	settings = g_settings_new ("org.gnome.evolution.mail");
 	strv = g_settings_get_strv (settings, "labels");
 
 	for (ii = 0; strv && strv[ii]; ii++) {
@@ -1809,8 +1807,7 @@ camel_m365_store_maybe_disconnect (CamelM365Store *m365_store,
 	if (camel_service_get_connection_status (service) != CAMEL_SERVICE_CONNECTED)
 		return;
 
-	if (g_error_matches (error, SOUP_HTTP_ERROR, SOUP_STATUS_UNAUTHORIZED)) {
-		CamelSession *session;
+	if (g_error_matches (error, E_SOUP_SESSION_ERROR, SOUP_STATUS_UNAUTHORIZED)) {
 		ESourceRegistry *registry = NULL;
 
 		camel_service_disconnect_sync (service, FALSE, NULL, NULL);
@@ -1818,10 +1815,7 @@ camel_m365_store_maybe_disconnect (CamelM365Store *m365_store,
 		error->domain = CAMEL_SERVICE_ERROR;
 		error->code = CAMEL_SERVICE_ERROR_CANT_AUTHENTICATE;
 
-		session = camel_service_ref_session (service);
-
-		if (E_IS_MAIL_SESSION (session))
-			registry = e_mail_session_get_registry (E_MAIL_SESSION (session));
+		registry = e_source_registry_new_sync (NULL, NULL);
 
 		if (registry) {
 			ESource *source, *collection = NULL;
@@ -1839,7 +1833,7 @@ camel_m365_store_maybe_disconnect (CamelM365Store *m365_store,
 			g_clear_object (&source);
 		}
 
-		g_clear_object (&session);
+		g_clear_object (&registry);
 	}
 }
 
